## $Id: interfaces.py 16181 2020-07-24 07:36:58Z henrik $
##
## Copyright (C) 2011 Uli Fouquet & Henrik Bettermann
## This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2 of the License, or
## (at your option) any later version.
##
## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with this program; if not, write to the Free Software
## Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
##

import zope.i18nmessageid
from zope import schema
from zc.sourcefactory.basic import BasicSourceFactory
from waeup.kofa.interfaces import (SimpleKofaVocabulary,
    ISessionConfiguration, academic_sessions_vocab,
    ContextualDictSourceFactoryBase)

_ = MessageFactory = zope.i18nmessageid.MessageFactory('waeup.aaue')

class EnableScoreEditingGroupSource(ContextualDictSourceFactoryBase):
    """A source for filtering groups of students
    """
    DICT_NAME = 'ENABLE_SCORE_EDITING_GROUP_DICT'

# It's recommended to replicate all fields from the base package here.
class ICustomSessionConfiguration(ISessionConfiguration):
    """A session configuration object.
    """

    clearance_fee = schema.Float(
        title = _(u'Regular Acceptance Fee'),
        default = 0.0,
        required = True,
        )

    clearance_fee_fp = schema.Float(
        title = _(u'FP Acceptance Fee'),
        default = 0.0,
        required = True,
        )

    clearance_fee_ijmbe = schema.Float(
        title = _(u'IJMBE Acceptance Fee'),
        default = 0.0,
        required = True,
        )

    clearance_fee_pg = schema.Float(
        title = _(u'FT PG Acceptance Fee'),
        default = 0.0,
        required = True,
        )

    clearance_fee_ug_pt = schema.Float(
        title = _(u'PT and DSH UG Acceptance Fee'),
        default = 0.0,
        required = True,
        )

    clearance_fee_pg_pt = schema.Float(
        title = _(u'PT PG Acceptance Fee'),
        default = 0.0,
        required = True,
        )

    clearance_fee_med = schema.Float(
        title = _(u'Medical Acceptance Fee'),
        default = 0.0,
        required = True,
        )

    clearance_fee_dp = schema.Float(
        title = _(u'Diploma Acceptance Fee'),
        default = 0.0,
        required = True,
        )

    clearance_fee_bridge = schema.Float(
        title = _(u'Bridge Acceptance Fee'),
        default = 0.0,
        required = True,
        )

    booking_fee = schema.Float(
        title = _(u'Booking Fee'),
        default = 0.0,
        required = True,
        )

    transcript_fee_inter = schema.Float(
        title = _(u'International Transcript Fee'),
        default = 0.0,
        required = True,
        )

    transcript_fee_local = schema.Float(
        title = _(u'Local Transcript Fee'),
        default = 0.0,
        required = True,
        )

    # Additional fees in custom package

    maint_fee = schema.Float(
        title = _(u'Maintenance Fee'),
        default = 0.0,
        required = True,
        )

    transfer_fee = schema.Float(
        title = _(u'Transfer Fee'),
        default = 0.0,
        required = True,
        )

    penalty_ug = schema.Float(
        title = _(u'UG Penalty Fee'),
        default = 0.0,
        required = True,
        )

    penalty_pg = schema.Float(
        title = _(u'PG Penalty Fee'),
        default = 0.0,
        required = True,
        )

    late_registration_fee = schema.Float(
        title = _(u'Late Course Reg. Fee'),
        default = 0.0,
        required = True,
        )

    late_pg_registration_fee = schema.Float(
        title = _(u'Late PG Course Reg. Fee'),
        default = 0.0,
        required = True,
        )

    id_card_fee = schema.Float(
        title = _(u'Student ID Card Fee'),
        default = 0.0,
        required = True,
        )

    welfare_fee = schema.Float(
        title = _(u'AAU Student Welfare Assurance Fee'),
        default = 0.0,
        required = True,
        )

    union_fee = schema.Float(
        title = _(u'Student Union Due'),
        default = 0.0,
        required = True,
        )

    lapel_fee = schema.Float(
        title = _(u'AAU Lapel/File Fee'),
        default = 0.0,
        required = True,
        )

    matric_gown_fee = schema.Float(
        title = _(u'Matriculation Gown Fee'),
        default = 0.0,
        required = True,
        )

    concessional_fee = schema.Float(
        title = _(u'Concessional Fee'),
        default = 0.0,
        required = True,
        )

    gst_text_book_0_fee = schema.Float(
        title = _(u'Text Book Fee GST101 GST102 GST111 GST112'),
        default = 0.0,
        required = True,
        )

    gst_text_book_1_fee = schema.Float(
        title = _(u'Text Book Fee GST101 and GST102'),
        default = 0.0,
        required = True,
        )

    gst_text_book_2_fee = schema.Float(
        title = _(u'Text Book Fee GST111 and GST112'),
        default = 0.0,
        required = True,
        )

    gst_text_book_3_fee = schema.Float(
        title = _(u'Text Book Fee GST222'),
        default = 0.0,
        required = True,
        )

    ent_text_book_1_fee = schema.Float(
        title = _(u'Text Book Fee ENT201'),
        default = 0.0,
        required = True,
        )

    gst_registration_1_fee = schema.Float(
        title = _(u'Registration Fee GST101 GST102 GST111 GST112'),
        default = 0.0,
        required = True,
        )

    gst_registration_2_fee = schema.Float(
        title = _(u'Registration Fee GST222'),
        default = 0.0,
        required = True,
        )

    ent_registration_1_fee = schema.Float(
        title = _(u'Registration Fee ENT201'),
        default = 0.0,
        required = True,
        )

    #fac_dep_fee = schema.Float(
    #    title = _(u'Faculty and Departmental Dues'),
    #    default = 0.0,
    #    required = True,
    #    )

    restitution_fee = schema.Float(
        title = _(u'Restitution Fee'),
        default = 0.0,
        required = True,
        )

    sports_fee = schema.Float(
        title = _(u'Sports Development Fee'),
        default = 0.0,
        required = True,
        )

    library_fee = schema.Float(
        title = _(u'Library Development Fee UG'),
        default = 0.0,
        required = True,
        )

    library_pg_fee = schema.Float(
        title = _(u'Library Development Fee PG'),
        default = 0.0,
        required = True,
        )

    # Is being calculated in utils.py
    #sports_library_fee = schema.Float(
    #    title = _(u'Sports Development and PG Library Fee'),
    #    default = 0.0,
    #    required = True,
    #    )

    ict_fee = schema.Float(
        title = _(u'ICT Fee'),
        default = 0.0,
        required = True,
        )

    affidavit_fee = schema.Float(
        title = _(u'Affidavit Fee'),
        default = 0.0,
        required = True,
        )

    lab_1_fee = schema.Float(
        title = _(u'Faculty Laboratory Due (CHM102/PHY103/CSC101)'),
        default = 0.0,
        required = True,
        )

    lab_2_fee = schema.Float(
        title = _(u'Laboratory Due (BIO101/BIO111)'),
        default = 0.0,
        required = True,
        )

    coursereg_deadline = schema.Datetime(
        title = _(u'FT Course Reg. Deadline'),
        required = False,
        description = _('Example: ') + u'2011-12-31 23:59:59+01:00',
        )

    coursereg_deadline_pg = schema.Datetime(
        title = _(u'PG Course Reg. Deadline'),
        required = False,
        description = _('Example: ') + u'2011-12-31 23:59:59+01:00',
        )

    coursereg_deadline_pt = schema.Datetime(
        title = _(u'PT Course Reg. Deadline'),
        required = False,
        description = _('Example: ') + u'2011-12-31 23:59:59+01:00',
        )

    coursereg_deadline_dp = schema.Datetime(
        title = _(u'DP Course Reg. Deadline'),
        required = False,
        description = _('Example: ') + u'2011-12-31 23:59:59+01:00',
        )

    coursereg_deadline_found = schema.Datetime(
        title = _(u'FOUND Course Reg. Deadline'),
        required = False,
        description = _('Example: ') + u'2011-12-31 23:59:59+01:00',
        )

    coursereg_deadline_bridge = schema.Datetime(
        title = _(u'Bridge Course Reg. Deadline'),
        required = False,
        description = _('Example: ') + u'2011-12-31 23:59:59+01:00',
        )

    score_editing_enabled = schema.List(
        title = _(u'Score editing enabled'),
        value_type = schema.Choice(
            source = EnableScoreEditingGroupSource(),
            ),
        required = False,
        defaultFactory=list,
        )

    show_results = schema.List(
        title = _(u'Show course results'),
        value_type = schema.Choice(
            source = EnableScoreEditingGroupSource(),
            ),
        required = False,
        defaultFactory=list,
        )

    studylevel_repair_enabled = schema.Bool(
        title = _(u'Course list repair enabled'),
        description = _(u'If set, students will be able to add and delete courses.'),
        default = False,
        required = False,
        )

    interswitch_enabled = schema.Bool(
        title = _(u'Interswitch integration enabled'),
        default = False,
        )

    etranzact_webconnect_enabled = schema.Bool(
        title = _(u'Etranzact Webconnect integration enabled'),
        default = False,
        )

    etranzact_payoutlet_enabled = schema.Bool(
        title = _(u'Etranzact Payoutlet integration enabled'),
        default = False,
        )

    def getSessionString():
        """Returns the session string from the vocabulary.
        """


class ICustomSessionConfigurationAdd(ICustomSessionConfiguration):
    """A session configuration object in add mode.
    """

    academic_session = schema.Choice(
        title = _(u'Academic Session'),
        source = academic_sessions_vocab,
        default = None,
        required = True,
        readonly = False,
        )

ICustomSessionConfigurationAdd[
    'academic_session'].order =  ICustomSessionConfiguration[
    'academic_session'].order